Module classification

Module classification 

Importance classification of passages into categories.

Structs

ClassificationConfig
Classification configuration.
ClassifiedPassage
A passage that has been classified into zero or more ImportanceCategory values, with extracted entities/values where applicable.
PassageContext
Context about a passage needed for classification. Keeps classification decoupled from core types.

Enums

ImportanceCategory
A category of importance assigned to a passage during classification.

Functions

classify_passages
Classify passages into importance categories and apply supersession.