Module injection

Module injection 

Detection of prompt-injection-shaped content.

Structs

InjectionConfig
Configuration for progressive injection policy.

Functions

adjust_weights
Return a ScoringConfig with category weights redistributed according to the compaction-level priority table.
scale_budget
Compute the effective token budget based on compaction depth.