extract

Function extract 

pub fn extract(tokens: &[String], n: usize) -> Vec<String>
Generate n-grams from a token list.

Produces n-grams by sliding a window of size n over the tokens and joining with a single space.

Returns an empty vec if tokens.len() < n.