Module session

Module session 

Session grouping helpers (group_entries_by_session, SessionGroup).

Structs

SessionGroup
A grouped set of entries that belong to the same derived session.

Functions

group_entries_by_session
Groups entries by explicit session id, then by fallback timestamp proximity.