Session grouping helpers (group_entries_by_session, SessionGroup).
Structs
- Session
Group - A grouped set of entries that belong to the same derived session.
Functions
- group_
entries_ by_ session - Groups entries by explicit session id, then by fallback timestamp proximity.